@@ -33,11 +33,11 @@ JUNIPER_INTERNAL_OPTS = [
 class Juniper(netmiko_devices.NetmikoSwitch):
 
     ADD_NETWORK = (
-        'set vlans {network_id} vlan-id {segmentation_id}',
+        'set vlans {network_name} vlan-id {segmentation_id}',
     )
 
     DELETE_NETWORK = (
-        'delete vlans {network_id}',
+        'delete vlans {network_name}',
     )
 
     PLUG_PORT_TO_NETWORK = (
@@ -105,8 +105,8 @@ class Juniper(netmiko_devices.NetmikoSwitch):
         """Save the device's configuration.
 
         :param net_connect: a netmiko connection object.
-        :raises GenericSwitchNetmikoConfigError if saving the configuration
-            fails.
+        :raises: GenericSwitchNetmikoConfigError if saving the
+                 configuration fails.
         """
         # Junos configuration is transactional, and requires an explicit commit
         # of changes in order for them to be applied. Since committing requires
